#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_THREE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_THREE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/three.hpp>

#endif
